#####################################################################
# tc_pingtcp.rb
#
# Test case for the Net::PingTCP class. This test should be run via
# the 'test' or 'test_tcp' Rake task.
#####################################################################
require "test/unit"
require "net/ping/tcp"
include Net

class TC_PingTCP < Test::Unit::TestCase
   def setup
      @host = "www.ruby-lang.org"
      @tcp  = Ping::TCP.new(@host)
   end

   def test_version
      assert_equal("1.2.1", PingTCP::VERSION)
   end
   
   def test_ping
      assert_respond_to(@tcp, :ping)
      assert_nothing_raised{ @tcp.ping }
      assert_nothing_raised{ @tcp.ping(@host) }
   end

   def test_ping_aliases
      assert_respond_to(@tcp, :ping?)
      assert_respond_to(@tcp, :pingecho)
      assert_nothing_raised{ @tcp.ping? }
      assert_nothing_raised{ @tcp.ping?(@host) }
      assert_nothing_raised{ @tcp.pingecho }
      assert_nothing_raised{ @tcp.pingecho(@host) }
   end

   def test_ping_ecr_false
      msg = "+this test may fail depending on your network environment+"
      PingTCP.ecr = false
      assert_equal(false, @tcp.ping?, msg)
      assert_equal(false, @tcp.exception.nil?, "Bad exception data")
   end

   def test_ping_ecr_true
      msg = "+this test may fail depending on your network environment+"
      PingTCP.ecr = true
      assert_equal(true, @tcp.ping?, msg)
   end
   
   def test_ecr
      assert_respond_to(PingTCP, :econnrefused)
      assert_respond_to(PingTCP, :econnrefused=)
      assert_respond_to(PingTCP, :ecr)
      assert_respond_to(PingTCP, :ecr=)
      assert_raises(ArgumentError){ PingTCP.ecr = "blah" }
   end
   
   def test_duration
      assert_nothing_raised{ @tcp.ping }
      assert_respond_to(@tcp, :duration)
      assert_kind_of(Float, @tcp.duration, '+nil if the ping failed+')
   end

   def test_host
      assert_respond_to(@tcp, :host)
      assert_respond_to(@tcp, :host=)
      assert_equal('www.ruby-lang.org', @tcp.host)
   end

   def test_port
      assert_respond_to(@tcp, :port)
      assert_respond_to(@tcp, :port=)
      assert_equal(7, @tcp.port)
   end

   def test_timeout
      assert_respond_to(@tcp, :timeout)
      assert_respond_to(@tcp, :timeout=)
      assert_equal(5, @tcp.timeout)
   end

   def test_exception
      msg = "+this test may fail depending on your network environment+"
      assert_respond_to(@tcp, :exception)
      assert_nothing_raised{ @tcp.ping }
      assert_nil(@tcp.exception, msg)
   end

   def test_warning
      assert_respond_to(@tcp, :warning)
   end

   def teardown
      @host = nil
      @tcp  = nil
   end
end
