################################################################
# tc_pingudp.rb
#
# Test case for the Net::Ping::UDP class. This should be run
# via the 'test' or 'test_udp' Rake task.
#
# If someone could provide me a host where a udp ping actually
# works, I would appreciate it. :)
################################################################
require "test/unit"
require "net/ping/udp"
include Net

class TC_PingUDP < Test::Unit::TestCase
   def setup
      @host = "www.ruby-lang.org"
      @udp  = Ping::UDP.new(@host)
   end

   def test_version
      assert_equal("1.2.1", Ping::UDP::VERSION)
   end
   
   def test_ping
      assert_respond_to(@udp, :ping)
      assert_nothing_raised{ @udp.ping }
      assert_nothing_raised{ @udp.ping(@host) }
   end

   def test_ping_aliases
      assert_respond_to(@udp, :ping?)
      assert_respond_to(@udp, :pingecho)
      assert_nothing_raised{ @udp.ping? }
      assert_nothing_raised{ @udp.ping?(@host) }
      assert_nothing_raised{ @udp.pingecho }
      assert_nothing_raised{ @udp.pingecho(@host) }
   end

   def test_ping_standard
      assert_equal(false, @udp.ping?)
      assert_equal(false, @udp.exception.nil?, "Bad exception data")
   end

   def test_bind
      assert_respond_to(@udp, :bind)
      assert_nothing_raised{ @udp.bind('www.ruby-lang.org', 80) }
   end
   
   def test_duration
      assert_nothing_raised{ @udp.ping }
      assert_respond_to(@udp, :duration)
      assert_kind_of(Float, @udp.duration)
   end

   def test_host
      assert_respond_to(@udp, :host)
      assert_respond_to(@udp, :host=)
      assert_equal('www.ruby-lang.org', @udp.host)
   end

   def test_port
      assert_respond_to(@udp, :port)
      assert_respond_to(@udp, :port=)
      assert_equal(7, @udp.port)
   end

   def test_timeout
      assert_respond_to(@udp, :timeout)
      assert_respond_to(@udp, :timeout=)
      assert_equal(5, @udp.timeout)
   end

   def test_exception
      assert_respond_to(@udp, :exception)
      assert_nothing_raised{ @udp.ping }
      assert_nil(@udp.exception)
   end

   def test_warning
      assert_respond_to(@udp, :warning)
   end

   def teardown
      @host = nil
      @udp  = nil
   end
end
